@@ -25,6 +25,8 @@
 
 extern size_t mstime();
 extern char *GamePath(char *dest, char *basedir, char *gamedir);
+extern qboolean FileExists(char *filename);
+extern int ExpandString(char *dest, int len, char *src, char format[256][32]);
 
 extern int Argc(char *s);
 extern char *Argv(char *s, int index);
