@@ -705,13 +705,14 @@ line_entity:
 					if (dm2->svd.version != 26)
 						ReadByte(src);		// ???
 					count = ReadByte(src);
-//					gi.dprintf(" Count: %d", count);
-
 					for (i = 0; i < count; i++)
 						current->areas[i] = ReadByte(src);
 
 					if (dm2->svd.isdemo == RECORD_RELAY)
 					{
+						for (i = 1; i <= numportals; i++)
+							gi.SetAreaPortalState(i, ISBITSET(current->areas, i));
+
 						count = ReadByte(src);
 						for (i = 0; i < count; i++)
 							current->connected[i] = ReadByte(src);
